@@ -1,17 +1,21 @@
 use bevy::prelude::*;
 
 use bevy_ascii_terminal::{terminal::Terminal, TerminalBundle, TerminalPlugin};
+use bevy_pixel_camera::{PixelBorderPlugin, PixelCameraBundle, PixelCameraPlugin};
 
 fn spawn_terminal(mut commands: Commands) {
-    let mut term_bundle = TerminalBundle::with_size(20, 3);
+    let (w, h) = (20, 3);
+    let mut term_bundle = TerminalBundle::with_size(w, h);
 
     term_bundle.terminal.draw_border_single();
     term_bundle.terminal.put_string(1, 1, "Press spacebar");
+
     commands.spawn_bundle(term_bundle);
 
-    let mut cam = OrthographicCameraBundle::new_2d();
-    cam.orthographic_projection.scale = 1.0 / 2.0;
-    commands.spawn_bundle(cam);
+    commands.spawn_bundle(PixelCameraBundle::from_resolution(
+        w as i32 * 12,
+        h as i32 * 12,
+    ));
 }
 
 fn hello_world(keys: Res<Input<KeyCode>>, mut q: Query<&mut Terminal>) {
@@ -28,6 +32,10 @@ fn main() {
     App::build()
         .add_plugins(DefaultPlugins)
         .add_plugin(TerminalPlugin)
+        .add_plugin(PixelCameraPlugin)
+        .add_plugin(PixelBorderPlugin {
+            color: Color::BLACK,
+        })
         .add_startup_system(spawn_terminal.system())
         .add_system(hello_world.system())
         .run()
