@@ -40,14 +40,16 @@ impl TerminalRendererVertexData {
         self.verts.resize(len * 4, Default::default());
         self.indices.resize(len * 6, 0);
 
-        let (tx, ty) = tile_size.into();
+        let (tile_width, tile_height) = tile_size.into();
 
         for i in 0..len {
-            let x = (i % term_size.x as usize) as f32 * tx;
-            let y = (i / term_size.x as usize) as f32 * ty;
+            let x = (i % term_size.x as usize) as f32 * tile_width;
+            // Flip y: y0 == the top of the terminal
+            let y = size.y as usize - 1 - (i / term_size.x as usize);
+            let y = y as f32 * tile_height;
             let origin = Vec3::new(x, y, 0.0) + term_pivot + tile_pivot;
-            let right = Vec3::X * tx;
-            let up = Vec3::Y * ty;
+            let right = Vec3::X * tile_width;
+            let up = Vec3::Y * tile_height;
 
             let vi = i * 4;
             // 0---2
